Folder "DevScripts"
===================

This folder contains helper scripts for the development of DHParser.
**These scripts are experimental and horribly outdated!**

* collect_symbols.py - Lists all exported symbols from DHParser modules

* create_standalone.py - merges the DHParser modules into a standalone
                        DHParser.py module for easier deployment.
